@@ -2,9 +2,14 @@
 import logging
 import os
 import time
+from os.path import join
+from dotenv import load_dotenv
 # from .thing import Thing
 from .properties.property import Property
 
+dotenv_path = join(os.getcwd(), '.env')
+load_dotenv(dotenv_path)
+
 class ThingLogger:
 
     def __init__(self, thing):
